#
# spec file for package openslp
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libslp1
Name:           openslp
Version:        2.0.0
Release:        22.3
Summary:        An Implementation of Service Location Protocol V2
License:        BSD-3-Clause
Group:          System/Daemons
URL:            http://www.openslp.org/
Source0:        http://sourceforge.net/projects/openslp/files/2.0.0/%{version}/%{name}-%{version}.tar.gz
Source2:        README.SUSE
Source3:        openslp.desktop
Source4:        openslp-devel.desktop
Source5:        openslp.logrotate
Source8:        baselibs.conf
Source9:        slpd.service
Source10:       openslp.logrotate.systemd
Patch1:         openslp.audit.diff
Patch2:         extensions.diff
Patch3:         openslp.truncate.diff
Patch4:         openslp.netlink.diff
Patch5:         openslp.initda.diff
Patch6:         openslp.visibility.diff
Patch7:         openslp.daemon.diff
Patch8:         openslp.cloexec.diff
Patch9:         openslp.hardmtu.diff
Patch10:        openslp.tcplocal.diff
Patch11:        openslp.localtime.diff
Patch12:        openslp.sd_notify.diff
Patch13:        openslp.predicatestorage.diff
Patch14:        openslp.doubleequal.diff
Patch15:        openslp.noconvenience.diff
Patch16:        openslp.xrealloc.diff
Patch17:        openslp.foldws.diff
Patch18:        openslp.openssl-1.1.diff
Patch19:        openslp.localaddr.diff
Patch20:        openslp.tcpunicast.diff
Patch21:        openslp-2.0.0-ifdef-slpv2.diff
Patch22:        openslp.tcpknownda.diff
Patch23:        openslp.nullattr.diff
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  libtool
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(zlib)

%description
Service Location Protocol is an IETF standards track protocol that
provides a framework that allows networking applications to discover
the existence, location, and configuration of networked services in
networks.

OpenSLP is an open source implementation of the SLPv2 protocol as
defined by RFC 2608 and RFC 2614.  This package includes the slptool
and runtime libraries.

%package server
Summary:        The OpenSLP Implementation of the Service Location Protocol V2
Group:          System/Daemons
Requires:       openslp
Requires(pre):  group(daemon)
Requires(pre):  shadow
Recommends:     logrotate
%{?systemd_requires}

%description server
Service Location Protocol is an IETF standards track protocol that
provides a framework that allows networking applications to discover
the existence, location, and configuration of networked services in
networks.

This package contains the SLP server. Every system, which provides any
services that should be used via an SLP client must run this server and
register the service.

%package -n %{libname}
Summary:        An Implementation of the Service Location Protocol V2
Group:          System/Libraries

%description -n %{libname}
Service Location Protocol is an IETF standards track protocol that
provides a framework that allows networking applications to discover
the existence, location, and configuration of networked services in
networks.

%package devel
Summary:        Header files for OpenSLP
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       openssl-devel

%description devel
Service Location Protocol is an IETF standards track protocol that
provides a framework that allows networking applications to discover
the existence, location, and configuration of networked services in
networks.

This package contains header and library files to compile applications
with SLP support. It also contains developer documentation to develop
such applications.

%prep
%setup -q
%patch -P 1
%patch -P 2
%patch -P 3
%patch -P 4
%patch -P 5
%patch -P 6
%patch -P 7
%patch -P 8
%patch -P 9
%patch -P 10
%patch -P 11
%patch -P 12
%patch -P 13
%patch -P 14
%patch -P 15
%patch -P 16
%patch -P 17
%patch -P 18 -p2
%patch -P 19
%patch -P 20
%patch -P 21 -p1
%patch -P 22
%patch -P 23

%build
autoreconf -fiv
%configure \
  --disable-static \
  --with-pic \
  --enable-slpv1 \
  --enable-async-api \
  --enable-slpv2-security
make %{?_smp_mflags}

%install
mkdir -p %{buildroot}%{_sysconfdir}/slp.reg.d
mkdir -p %{buildroot}%{_sysconfdir}/slp.reg.d/slpd
cp etc/slp.conf %{buildroot}%{_sysconfdir}
cp etc/slp.reg %{buildroot}%{_sysconfdir}
cp etc/slp.spi %{buildroot}%{_sysconfdir}
mkdir -p %{buildroot}/%{_libdir}
./libtool --mode=install install libslp/libslp.la %{buildroot}/%{_libdir}
rm %{buildroot}%{_libdir}/libslp.la
mkdir -p  %{buildroot}%{_sbindir}
./libtool --mode=install install slpd/slpd %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_bindir}
./libtool --mode=install install slptool/slptool %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_includedir}
cp libslp/slp.h %{buildroot}%{_includedir}
mkdir -p %{buildroot}%{_defaultdocdir}/%{name}
find . -name CVS -o -name .cvsignore -o -name .xvpics | xargs rm -rf
cp -a AUTHORS README FAQ doc/doc/rfc doc/doc/html %{SOURCE2} \
   %{buildroot}%{_defaultdocdir}/%{name}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcslpd
cat > %{buildroot}%{_sbindir}/rcopenslp <<'EOF'
#!/bin/sh
exec %{_sbindir}/rcslpd "$@"
EOF
chmod 755 %{buildroot}%{_sbindir}/rcopenslp
%if 0%{?suse_version} > 1500
mkdir -p %{buildroot}%{_distconfdir}/logrotate.d
install -D -m 0644 %{SOURCE10} %{buildroot}%{_distconfdir}/logrotate.d/openslp-server
%else
install -D -m 0644 %{SOURCE10} %{buildroot}%{_sysconfdir}/logrotate.d/openslp-server
%endif
# install susehelp file
mkdir -p %{buildroot}%{_datadir}/susehelp/meta/Administration/
install -m 0644 %{SOURCE3} \
	%{buildroot}%{_datadir}/susehelp/meta/Administration/
mkdir -p %{buildroot}%{_datadir}/susehelp/meta/Development/Libraries/
install -m 0644 %{SOURCE4} \
	%{buildroot}%{_datadir}/susehelp/meta/Development/Libraries/

install -D -m 644 %{SOURCE9} %{buildroot}%{_unitdir}/slpd.service

#XXX test suite requires root
#check
#make check

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%pre server
getent passwd openslp >/dev/null || useradd -r -g daemon -d %{_localstatedir}/lib/empty -s /sbin/nologin -c "openslp daemon" openslp
%service_add_pre slpd.service
%if 0%{?suse_version} > 1500
# Prepare for migration to /usr/etc; save any old .rpmsave
for i in logrotate.d/openslp-server ; do
   test -f %{_sysconfdir}/${i}.rpmsave && mv -v %{_sysconfdir}/${i}.rpmsave %{_sysconfdir}/${i}.rpmsave.old ||:
done
%endif

%if 0%{?suse_version} > 1500
%posttrans server
# Migration to /usr/etc, restore just created .rpmsave
for i in logrotate.d/openslp-server ; do
   test -f %{_sysconfdir}/${i}.rpmsave && mv -v %{_sysconfdir}/${i}.rpmsave %{_sysconfdir}/${i} ||:
done
%endif

%post server
%service_add_post slpd.service

%postun server
%service_del_postun slpd.service

%preun server
%service_del_preun slpd.service

%files -n %{libname}
%{_libdir}/libslp.so.*

%files
%license COPYING
%dir %{_defaultdocdir}/%{name}
%dir %{_defaultdocdir}/%{name}/html
%doc %{_defaultdocdir}/%{name}/AUTHORS
%doc %{_defaultdocdir}/%{name}/README
%doc %{_defaultdocdir}/%{name}/README.SUSE
%{_bindir}/slptool
%config(noreplace) %{_sysconfdir}/slp.conf
%config(noreplace) %{_sysconfdir}/slp.spi

%files server
%dir %{_datadir}/susehelp
%dir %{_datadir}/susehelp/meta
%dir %{_datadir}/susehelp/meta/Administration
%doc %{_defaultdocdir}/%{name}/FAQ
%doc %{_defaultdocdir}/%{name}/html/IntroductionToSLP
%doc %{_defaultdocdir}/%{name}/html/UsersGuide
%doc %{_defaultdocdir}/%{name}/html/faq.html
%doc %{_defaultdocdir}/%{name}/rfc
%doc %{_datadir}/susehelp/meta/Administration/openslp.desktop
%dir %{_sysconfdir}/slp.reg.d/
%dir %{_sysconfdir}/slp.reg.d/slpd
%{_sbindir}/rcopenslp
%{_sbindir}/rcslpd
%{_sbindir}/slpd
%config(noreplace) %{_sysconfdir}/slp.reg
%if 0%{?suse_version} > 1500
%{_distconfdir}/logrotate.d/openslp-server
%else
%config(noreplace) %{_sysconfdir}/logrotate.d/openslp-server
%endif
%{_unitdir}/slpd.service

%files devel
%dir %{_datadir}/susehelp
%dir %{_datadir}/susehelp/meta
%dir %{_datadir}/susehelp/meta/Development
%dir %{_datadir}/susehelp/meta/Development/Libraries
%doc %{_defaultdocdir}/%{name}/html/ProgrammersGuide
%doc %{_datadir}/susehelp/meta/Development/Libraries/openslp-devel.desktop
%{_includedir}/slp.h
%{_libdir}/libslp.so

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Aug 31 2022 Stefan Schubert <schubi@suse.com>
- Migration to /usr/etc: Saving user changed configuration files
  in /etc and restoring them while an RPM update.
* Tue Jun 21 2022 Stefan Schubert <schubi@suse.com>
- Moved logrotate files from user specific directory /etc/logrotate.d
  to vendor specific directory /usr/etc/logrotate.d.
* Wed Oct 13 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * slpd.service
* Tue Mar 24 2020 mls@suse.de
- Add missing openslp requires to the openslp-server package
  [bnc#1165121]
* Thu Jul 25 2019 matthias.gerstner@suse.com
- removal of SuSEfirewall2 service, since SuSEfirewall2 has been replaced by
  firewalld, see [1].
  [1]: https://lists.opensuse.org/opensuse-factory/2019-01/msg00490.html
* Wed Jun 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Explicitely require library on develpackage and do not pull
  in the base package with slptool binary
* Sun Jun  9 2019 Jan Engelhardt <jengelh@inai.de>
- Fixup summaries: SDK already includes "development",
  and shared library is unspecific. Remove marketing wording
  from descriptions.
* Fri Jun  7 2019 mls@suse.de
- Use tcp connects to talk with other DAs [bnc#1117969]
  new patch: openslp.tcpknownda.diff
- Fix segfault in predicate match if a registered service has
  a malformed attribute list [bnc#1136136]
  new patch: openslp.nullattr.diff
* Thu Jun  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Remove < SLE12 as it is no longer supported
- Remove obsolete conditions/etc.
  * dropped file: slpd.init
- Cleanup with spec-cleaner
- Split out shared library properly
* Thu Jun  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Drop the omc config fate#301838:
  * it is obsolete since SLE11
* Mon Aug 27 2018 Jason Sikes <jsikes@suse.de>
- Fixed failure to compile when ENABLE_SLPv2_SECURITY is not set
  new patch: openslp-2.0.0-ifdef-slpv2.diff
* Wed Apr 11 2018 mls@suse.de
- move systemd notification before the chroot() call, otherwise
  the notify function cannot reach systend's unix domain socket
  [bnc#1089097]
* Thu Mar  1 2018 mls@suse.de
- Use %%license (boo#1082318)
- fix slpd using the peer address as local address for TCP
  connections [bnc#1076035]
  new patch: openslp.localaddr.diff
- use tcp connections for unicast requests [bnc#1080964]
  new patch: openslp.tcpunicast.diff
* Wed Nov 29 2017 ro@suse.de
- add separate source openslp.logrotate.systemd to
  use systemctl reload for logrotate configuration
* Tue Jun 13 2017 daniel.molkentin@suse.com
- Add support for OpenSSL 1.1. Commit from upstream [bsc#1042665]
  new patch: openslp.openssl-1.1.diff
* Mon Jan  9 2017 fbui@suse.com
- Also update openslp.sd_notify.diff to use the new systemd lib
* Mon Dec 12 2016 fbui@suse.com
- Replace pkgconfig(libsystemd-*) with pkgconfig(libsystemd)
  Nowadays pkgconfig(libsystemd) replaces all libsystemd-* libs, which
  are obsolete.
* Wed Oct 12 2016 mls@suse.de
- Fix bounds check in SLPFoldWhiteSpace
  [bnc#1001600] [CVE-2016-7567]
  new patch: openslp.foldws.diff
* Mon Sep 12 2016 mls@suse.de
- remove convenience code as changes bytes in the message
  buffer breaking the verification code [bnc#994989]
  new patch: openslp.noconvenience.diff
- fix storage handling in predicate code, it clashed with gcc's
  fortify_source extension [bnc#909195]
  new patch: openslp.predicatestorage.diff
- bring back allowDoubleEqualInPredicate option
  new patch: openslp.doubleequal.diff
- fix bug in openslp.initda.diff patch
- fix rcopenslp helper
- fix _xrealloc not checking the malloc return value
  [bnc#980722] [CVE-2016-4912]
  new patch: openslp.xrealloc.diff
* Sun Mar  8 2015 p.drouand@gmail.com
- Do not depend on fillup and insserv if the package build with
  systemd support; the dependencies are not needed in that case
* Mon Sep  1 2014 mls@suse.de
- fix last commit
* Mon Jul 28 2014 crrodriguez@opensuse.org
- Do not apply previous patch to distros without systemd.
- Limit init script usage only to legacy products.
* Sun Jul 27 2014 crrodriguez@opensuse.org
- openslp.sd_notify.diff make slpd systemd service of type
  notify instead of simple, to avoid startup races.
* Thu Apr 10 2014 mls@suse.de
- use AI_CANONNAME when looking up the canonical name
* Wed Feb 19 2014 mls@suse.de
- update to openslp-2.0.0 to get IPv6 support
  * dropped patches:
    v1dadiscovery.diff, openslp.clrflags.diff
    openslp.fixdsareturn.diff, openslp.dereg.diff,
    openslp.tcpclearovr.diff, openslp.lifetime.diff,
    slptool-timeout.diff, openslp.poll.diff,
    openslp.ignorespaces.diff, openslp.checkovr.diff,
    openslp.fixaddrcheck.diff, openslp.loopbacksocket.diff,
    openslp.diff, openslp.doubleequal.diff, openslp.discovery.diff,
    openslp.parseext.diff, openslp.knowndafree.diff,
    openslp.emptyanswer.diff, openslp.v1sladdr.diff, hppa.diff
  * renamed patches:
    openslp-1.2.0-visibility.patch -> openslp.visibility.diff
    openslp-1.2.0-daemon.diff -> openslp.daemon.diff
    openslp.use-TCPDIAG-for-checking-listeners -> openslp.netlink.diff
    openslp-ocloexec.patch -> openslp.cloexec.diff
- always use localtime in the log file [bnc#855385]
  patch: openslp.localtime.diff
- use tcp to connect to the local SA
  patch: openslp.tcplocal.diff
- drop unused mdns support
- rename README.SuSE to README.SUSE
* Thu Feb 13 2014 mls@suse.de
- frontport SLE11 patches:
  * add hardMTU option to limit the datagram package size to
    1400 bytes [bnc#648384].
    patch: openslp.hardmtu.diff
  * fix double free in SLPDKnownDAAdd error case [bnc#667953]
    patch: openslp.knowndafree.diff
  * fix libslp socket handling, check if socket is still alive
    and fix socket close code [bnc#693756]
    patch: openslp.loopbacksocket.diff
  * make openslpd reconnect to DAs if they closed the connection
    [bnc#723385]
    patch: openslp.slpdreconnect.diff
  * fixup lifetime of registrations a bit so that they
    don't get removed too early [bnc#658972]
    patch: openslp.lifetime.diff
* Tue Jul 16 2013 mls@suse.de
- fix wrong dir modifier in filelist
* Mon Apr 15 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Thu Oct 18 2012 coolo@suse.com
- buildrequire systemd through the pkgconfig provide to get
  systemd-mini in build environments (to break cycles)
* Sat Aug 25 2012 crrodriguez@opensuse.org
- openslp-ocloexec.patch: open all internal fds with O_CLOEXEC
  so we do not leak them on fork() .. execve() particulary
  important in the shared library.
* Wed Feb  8 2012 coolo@suse.com
- move the systemd requires to the server subpackage
* Thu Dec 22 2011 crrodriguez@opensuse.org
- Add native systemd unit
* Wed Nov 16 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Mon Feb 28 2011 lnussel@suse.de
- use dedicated user instead of 'daemon' (bnc#656780)
* Fri Nov  5 2010 cristian.rodriguez@opensuse.org
- libslp: export only functions of the public interface
  defined in slp.h
* Tue Oct 12 2010 mls@suse.de
- fix extension parsing code, CVE-2010-3609 [bnc#642571]
* Fri Oct  1 2010 mls@suse.de
- ignore leading and trailing spaces when comparing strings
  [bnc#626444]
* Thu Sep 30 2010 mls@suse.de
- change DA pull code to not use the pulled-from-de prediacte, but
  instead don't overwrite non-pulled registrations
* Thu Jul 29 2010 mls@suse.de
- add DABackupLocalReg option to enable backup of local services
  [bnc#597215]
* Tue May 11 2010 jeffm@suse.de
- avoid CPU usage spike while while reading /proc/net/tcp
  on systems with many connections (bnc#601002)
* Wed Apr 28 2010 mls@suse.de
- do not ignore DA answers if active and passive DA detection is off
  [bnc#564504]
- add DASyncReg and isDABackup options for OES folks
* Fri Mar 12 2010 kkaempf@novell.com
- Add SuSEfirewall2 description file
* Mon Dec 14 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Wed Nov 18 2009 mls@suse.de
- clear mcast flag from DAAdverts [bnc#533432]
* Fri Jan 30 2009 mls@suse.de
- fix DSA_verify return code test [bnc#465270]
* Thu Jan 22 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Fri Nov 14 2008 mrueckert@suse.de
- enable service only on sles 9 and 10 by default
- remove deprecated usage of run_ldconfig
- recommend logrotate in the server package
* Mon Aug 18 2008 ro@suse.de
- move prereq to server subpackage
- fix init script
* Fri May  9 2008 schwab@suse.de
- Fix use of libtool.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Tue Apr  1 2008 mkoenig@suse.de
- remove dir /usr/share/omc/svcinfo.d as it is provided now
  by filesystem
* Tue Mar 25 2008 mls@suse.de
- fix non-intel little-endian platforms [bnc#372179]
* Wed Mar 19 2008 mls@suse.de
- initialize peeraddr in unicast case [bnc#370374]
* Tue Sep  4 2007 mls@suse.de
- fix typo in dereg code [#290333]
* Thu Mar 29 2007 rguenther@suse.de
- add bison and flex BuildRequires
* Thu Jan 11 2007 ro@suse.de
- move omc xml file to /usr/share/omc
* Mon Jan  8 2007 ro@suse.de
- move srvinfo.d to svcinfo.d (typo in fate entry)
* Mon Dec 18 2006 ro@suse.de
- added slpd.xml to /etc/omc/srvinfo.d (fate#301831)
* Thu Nov 16 2006 mls@suse.de
- truncate oversized udp messages, finally fixes [#185483]
  (can be turned of with "net.slp.oversizedUDP" option)
- do not try to send back empty answers
- add option "net.slp.allowDoubleEqualInPredicate" to make openslp
  work with some buggy clients that use "==" for comparison [#95043]
- changed SLPGetPeer interface to support IPv6
* Tue Sep 12 2006 mls@suse.de
- obey OVERFLOW bit of incoming udp messages [#185483]
- use right length in send() calls [#185483]
- fix errno check in IncomingStreamWrite
- add SLPGetPeer method in libslp
- add --peerinfo option to slptool to print peerinfo
* Wed May 10 2006 mls@suse.de
- fix unaligned memory access on ia64 [#171932]
* Fri Mar 24 2006 mls@suse.de
- fix listening on multiple interfaces [#160008]
* Sat Mar 18 2006 schwab@suse.de
- Fix file descritor leak [#159303].
* Mon Jan 30 2006 mls@suse.de
- fix bug in DropSLPMulticastGroup
- add -fstack-protector to CFLAGS
- added logrotate script [#143069]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Dec 23 2005 mls@suse.de
- clear overflow bit on TCP connections [#135248]
* Thu Sep 29 2005 dmueller@suse.de
- add norootforbuild
* Mon Aug 22 2005 mls@suse.de
- also listen on SLPv1 General Multicast address [#64138]
- use poll instead of select [#65673]
* Tue Feb 15 2005 mls@suse.de
- update to version 1.2.0
- fixed security audit findings
- disable mdns in slpd for now, libslp still supports it
* Fri Dec  3 2004 mls@suse.de
- fix slpv DA discovery scope handling (#48728)
- use _dns-sd instead of _mdns in mdns findsrvtypes query (#48325)
* Thu Oct 14 2004 adrian@suse.de
- add meta information for suse help.
* Sun Jun 13 2004 bg@suse.de
- reduce hardcoded optimization from -O3 to -O2 to circumvent
  ICE on hppa
* Tue Jun  1 2004 mls@suse.de
- added fillup and insserv prereq
* Thu May 27 2004 mls@suse.de
- use /proc/net/tcp_listen and /proc/net/tcp6_listen if
  available to keep things fast on systems with lots of
  network connections [#40888]
* Wed May  5 2004 mls@suse.de
- treat empty attributes as illegal [#39669]
- always start slpd on SLES [#39863]
* Fri Apr 23 2004 mls@suse.de
- libslp: use configured TTL settings [#39030]
* Fri Apr  2 2004 mls@suse.de
- beta is over, don't always start slpd
* Fri Apr  2 2004 kukuk@suse.de
- Fix init script
* Wed Mar 31 2004 mls@suse.de
- fix sighup processing
- clean up spi code
- fix spi null pointer reference
- fix namingauth comparison
- added try-restart to rcslpd
- fix slp.conf re-read
- fix prlist buffer overrun
* Mon Mar 29 2004 mls@suse.de
- turn around srvtypes order in mdns
* Thu Mar 18 2004 mls@suse.de
- code cleanup
- provide A RR with SRV RRs
- don't pack .xvpics
* Fri Mar 12 2004 mls@suse.de
- added missing SLPGetMDNSName prototype to slp.h
* Fri Mar 12 2004 mls@suse.de
- slpd: fix hostname detection segfault
- slpd: use ttl 255 for mdns
- slpd: put attrs in mdns TXT RR
- libslp: check mdns ttl
- libslp: make getattr work with mdns
- libslp: make mdns name available via new SLPGetMDNSName() function
* Thu Mar  4 2004 mls@suse.de
- libslp: add scope/nameingauth/predicate to query
- slpd: reply to mdns service requests
- slpd: don't play DA if our hostname expands to loopback
- slpd: fix null pointer reference if SrvReg request is sent
  over tcp (as done by apple)
* Fri Feb 27 2004 mls@suse.de
- slpd: check port status every 15 seconds for watch-port-tcp/udp
  entries
- libslp: send MDNS queries for scope _mdns
* Sun Feb 15 2004 adrian@suse.de
- export full qualified hostnames for $HOSTNAME
- replace several $HOSTNAME tags in a srvurl
- do only accept .reg files (no .rpmsave for instance)
* Sat Feb 14 2004 adrian@suse.de
- fix /proc/net/tcp* parsing
- ONLY FOR BETA: start slpd always
* Thu Jan 29 2004 adrian@suse.de
- fix reading from slpd.reg.d directory
  (was broken since chroot run)
* Wed Jan 14 2004 adrian@suse.de
- slptool register now services with max timeout.
* Tue Dec 16 2003 adrian@suse.de
- fix sig11 when using the library without spi file
* Mon Dec  8 2003 adrian@suse.de
- security enhancements:
  * use chroot and open needed file descriptors before
  * panic if chroot or setuid fails
  * pid-file= option in reg files is useless now, so
    tcp-port= must be used for this now
- add SSL support again
* Wed Nov 26 2003 adrian@suse.de
- add buffer fix from cvs
- add README.SuSE with config howto
* Thu Nov 20 2003 adrian@suse.de
- drop the multicast route creation in runlevel script.
  we do not need it anymore with 1.1.5
* Wed Nov 19 2003 adrian@suse.de
- update to version 1.1.5
  * development version, but it contains lots of fixes
- use $HOSTNAME instead of $LOCALHOST in reg files
* Fri Nov 14 2003 adrian@suse.de
- use correct keyword "X-UnitedLinux-Should-Start" in init script
  (seen by Martin Vidner)
* Thu Nov 13 2003 adrian@suse.de
- add "tcp-port=" option to test services running via (x)inted
- start after (x)inetd
* Wed Nov 12 2003 adrian@suse.de
- add code to parse .reg files from any package below /etc/slp.reg.d/
* Sun Nov  9 2003 adrian@suse.de
- fix security issue in init script
* Sat Nov  8 2003 adrian@suse.de
- initial package of version 1.0.11
